OperatorBuilder

Struct OperatorBuilder 

pub struct OperatorBuilder<'scope, T: Timestamp> { /* private fields */ }
Builds operators with generic shape.

Implementations

Source

impl<'scope, T: Timestamp> OperatorBuilder<'scope, T>

pub fn new(name: String, scope: Scope<'scope, T>) -> Self

Allocates a new generic operator builder from its containing scope.

pub fn index(&self) -> usize

The operator’s scope-local index.

pub fn global(&self) -> usize

The operator’s worker-unique identifier.

pub fn shape(&self) -> &OperatorShape

Return a reference to the operator’s shape

pub fn set_notify_for(&mut self, input: usize, notify: FrontierInterest)

Sets frontier interest for a specific input.

pub fn new_input<C: Container, P>( &mut self, stream: Stream<'scope, T, C>, pact: P, ) -> P::Puller
where P: ParallelizationContract<T, C>,

Adds a new input to a generic operator builder, returning the Pull implementor to use.

pub fn new_input_connection<C: Container, P, I>( &mut self, stream: Stream<'scope, T, C>, pact: P, connection: I, ) -> P::Puller
where P: ParallelizationContract<T, C>, I: IntoIterator<Item = (usize, Antichain<<T as Timestamp>::Summary>)>,

Adds a new input to a generic operator builder, returning the Pull implementor to use.

pub fn new_output<C: Container>(&mut self) -> (Tee<T, C>, Stream<'scope, T, C>)

Adds a new output to a generic operator builder, returning the Push implementor to use.

pub fn new_output_connection<C: Container, I>( &mut self, connection: I, ) -> (Tee<T, C>, Stream<'scope, T, C>)
where I: IntoIterator<Item = (usize, Antichain<<T as Timestamp>::Summary>)>,

Adds a new output to a generic operator builder, returning the Push implementor to use.

pub fn build<L>(self, logic: L)
where L: FnMut(&mut SharedProgress<T>) -> bool + 'static,

Creates an operator implementation from supplied logic constructor.

Boxes the closure to avoid per-closure monomorphization based on L. For the fully generic (non-boxing) path, see [build_typed].

pub fn build_boxed(self, logic: Box<dyn FnMut(&mut SharedProgress<T>) -> bool>)

Creates an operator implementation from pre-boxed logic.

This method exists primarily to force the Box<dyn ...> coercion, which can otherwise easily be Box<L> for specialized L instead.

pub fn build_typed<L>(self, logic: L)
where L: FnMut(&mut SharedProgress<T>) -> bool + 'static,

Like build_reschedule, but specialized to the closure type L.

This method is instantiated once per distinct L, and one should be mindful of monomorphization bloat. Callers with many distinct closures should consider erasing their variation, for example via Box<dyn ...>, as demonstrated in [build].

pub fn operator_info(&self) -> OperatorInfo

Information describing the operator.